@@ -289,8 +289,7 @@ class BackgroundQueueWorker(BackgroundAsyncWorker):
 
     def put_threadsafe(self, t):
         if self._active or t is None:
-            return asyncio.run_coroutine_threadsafe(self._Q.put(t),
-                                                    loop=self.worker_loop)
+            return self.aloop.run_coroutine_threadsafe(self._Q.put(t))
 
     async def put(self, t):
         await self._Q.put(t)
